### R code from vignette source 'MINT-analysis.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: MINT-analysis.Rnw:148-149
###################################################
library(mixOmics)


###################################################
### code chunk number 2: MINT-analysis.Rnw:158-176
###################################################
data(stemcells)

#the combined data set X
X = stemcells$gene
dim(X) 

# the outcome vector Y:  
Y = stemcells$celltype 
length(Y) 
summary(Y)

# the vector indicating each independent study
study = stemcells$study
# number of samples per study:
summary(study)

# experimental design
table(Y,study)


###################################################
### code chunk number 3: >
###################################################
mint.plsda.res.perf = mint.plsda(X = X, Y = Y, study = study, ncomp = 5)

set.seed(2543)  # for reproducible result in this example
t1 = proc.time()
perf.mint.plsda.cell <- perf(mint.plsda.res.perf, validation = "Mfold", folds = 5, 
                  progressBar = FALSE, auc = TRUE) 
t2 = proc.time()
running_time = t2 - t1; running_time


###################################################
### code chunk number 4: MINT-analysis.Rnw:195-196
###################################################
plot(perf.mint.plsda.cell, col = color.mixo(5:7))


###################################################
### code chunk number 5: MINT-analysis.Rnw:203-204
###################################################
perf.mint.plsda.cell$global.error


###################################################
### code chunk number 6: MINT-analysis.Rnw:208-209
###################################################
perf.mint.plsda.cell$choice.ncomp


###################################################
### code chunk number 7: MINT-analysis.Rnw:214-218
###################################################
mint.plsda.res = mint.plsda(X = X, Y = Y, study = study, ncomp = 2)
#mint.plsda.res # lists the different functions
plotIndiv(mint.plsda.res, legend = TRUE, title = 'MINT PLS-DA', 
          subtitle = 'stem cell study', ellipse = T)


###################################################
### code chunk number 8: MINT-analysis.Rnw:231-239 (eval = FALSE)
###################################################
## t1 = proc.time()
## tune.mint = tune(X = X, Y = Y, study = study, ncomp = 2, test.keepX = seq(1, 100, 1), 
## method = 'mint.splsda', dist = "max.dist", progressBar = FALSE)
## t2 = proc.time()
## running_time = t2 - t1; running_time
## 
## #tune.mint   # lists the different types of outputs
## save(tune.mint, running_time,  file="RData/result-MINT-sPLSDA.RData")


###################################################
### code chunk number 9: MINT-analysis.Rnw:242-243
###################################################
load("RData/result-MINT-sPLSDA.RData")


###################################################
### code chunk number 10: MINT-analysis.Rnw:246-258 (eval = FALSE)
###################################################
## t1 = proc.time()
## tune.mint = tune(X = X, Y = Y, study = study, ncomp = 2, test.keepX = seq(1, 100, 1), 
## method = 'mint.splsda', dist = "max.dist", progressBar = FALSE)
## 
## t2 = proc.time()
## 
## # tune.mint   # lists the different types of outputs
## 
## # mean error rate per component and per tested keepX value
## # tune.mint$error.rate
## 
## running_time = t2 - t1; running_time


###################################################
### code chunk number 11: MINT-analysis.Rnw:261-262
###################################################
running_time


###################################################
### code chunk number 12: MINT-analysis.Rnw:266-273
###################################################
# optimal number of components
tune.mint$choice.ncomp #tune.mint$choice.ncomp # tell us again than ncomp=1 is sufficient

# optimal keepX
tune.mint$choice.keepX

plot(tune.mint, col = color.jet(2))


###################################################
### code chunk number 13: MINT-analysis.Rnw:280-284
###################################################
mint.splsda.res = mint.splsda(X = X, Y = Y, study = study, ncomp = 2,  
                              keepX = tune.mint$choice.keepX)

#mint.splsda.res   # lists useful functions that can be used with a MINT object


###################################################
### code chunk number 14: MINT-analysis.Rnw:289-290
###################################################
selectVar(mint.splsda.res, comp = 1)


###################################################
### code chunk number 15: MINT-analysis.Rnw:297-299
###################################################
plotIndiv(mint.splsda.res, study = 'global', legend = TRUE, title = 'MINT sPLS-DA', 
          subtitle = 'Global', ellipse=T)


###################################################
### code chunk number 16: MINT-analysis.Rnw:304-306
###################################################
plotIndiv(mint.splsda.res, study = 'all.partial',  title = 'MINT sPLS-DA', 
          subtitle = paste("Study",1:4))


###################################################
### code chunk number 17: MINT-analysis.Rnw:312-313
###################################################
plotArrow(mint.splsda.res)


###################################################
### code chunk number 18: MINT-analysis.Rnw:320-323
###################################################
cim(mint.splsda.res, comp = 1, margins=c(10,5), 
    row.sideColors = color.mixo(as.numeric(Y)), row.names = FALSE,
    title = "MINT sPLS-DA, component 1")


###################################################
### code chunk number 19: MINT-analysis.Rnw:329-332
###################################################
plotLoadings(mint.splsda.res, contrib="max", method = 'mean', comp=1, 
             study="all.partial", legend=FALSE, title="Contribution on comp 1", 
             subtitle = paste("Study",1:4))


###################################################
### code chunk number 20: MINT-analysis.Rnw:342-349
###################################################
set.seed(123)
t1 = proc.time()
perf.mint = perf(mint.splsda.res, progressBar = FALSE, dist = 'max.dist')
t2 = proc.time()
running_time = t2 - t1; running_time

perf.mint$global.error


###################################################
### code chunk number 21: MINT-analysis.Rnw:353-354
###################################################
plot(perf.mint, col = color.mixo(5))


###################################################
### code chunk number 22: MINT-analysis.Rnw:360-369
###################################################
# we predict on study 3
ind.test = which(study == "3")
test.predict <- predict(mint.splsda.res, newdata = X[ind.test, ], dist = "max.dist",
                        study.test = factor(study[ind.test]))
Prediction <- test.predict$class$max.dist[, 2]

# the confusion table compares the real subtypes with the predicted subtypes
get.confusion_matrix(truth = Y[ind.test],
                     predicted = Prediction)


###################################################
### code chunk number 23: MINT-analysis.Rnw:377-378
###################################################
auc.mint.splsda = auroc(mint.splsda.res, roc.comp = 2)


###################################################
### code chunk number 24: MINT-analysis.Rnw:383-384
###################################################
auc.mint.splsda = auroc(mint.splsda.res, roc.comp = 2, roc.study = '2')


###################################################
### code chunk number 25: MINT-analysis.Rnw:389-390
###################################################
sessionInfo()


###################################################
### code chunk number 26: MINT-analysis.Rnw:394-396
###################################################
# the end of that chapter. Command not to be run
Stangle('MINT-analysis.Rnw', encoding = 'utf8')


