### R code from vignette source 'PLSDA-analysis.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: PLSDA-analysis.Rnw:151-152
###################################################
library(mixOmics)


###################################################
### code chunk number 2: PLSDA-analysis.Rnw:157-162
###################################################
data(srbct)
X = srbct$gene  #the gene expression data
dim(X)

summary(srbct$class)


###################################################
### code chunk number 3: PLSDA-analysis.Rnw:170-173
###################################################
pca.srbct = pca(X, ncomp = 10, center = TRUE, scale = TRUE)
#pca.srbct #outputs the explained variance per component
plot(pca.srbct)  # screeplot of the eingenvalues (explained variance per component)


###################################################
### code chunk number 4: PLSDA-analysis.Rnw:181-183
###################################################
plotIndiv(pca.srbct, group = srbct$class, ind.names = FALSE, 
          legend = TRUE, title = 'PCA on SRBCT')


###################################################
### code chunk number 5: PLSDA-analysis.Rnw:192-194
###################################################
Y = srbct$class 
summary(Y)        #outcome categories


###################################################
### code chunk number 6: PLSDA-analysis.Rnw:202-206
###################################################
srbct.plsda <- plsda(X, Y, ncomp = 10)  # set ncomp to 10 for performance assessment later
plotIndiv(srbct.plsda , comp = 1:2,
          group = srbct$class, ind.names = FALSE, 
          ellipse = TRUE, legend = TRUE, title = 'PLSDA on SRBCT')


###################################################
### code chunk number 7: PLSDA-analysis.Rnw:217-224
###################################################
# with background
background = background.predict(srbct.plsda, comp.predicted=2, dist = "max.dist") 
#optional: xlim = c(-40,40), ylim = c(-30,30))

plotIndiv(srbct.plsda, comp = 1:2,
          group = srbct$class, ind.names = FALSE, title = "Maximum distance",
          legend = TRUE,  background = background)


###################################################
### code chunk number 8: PLSDA-analysis.Rnw:233-240
###################################################
# may take some time to run 
set.seed(2543) # for reproducibility
t1 = proc.time()
perf.plsda.srbct <- perf(srbct.plsda, validation = "Mfold", folds = 5, 
                  progressBar = FALSE, auc = TRUE, nrepeat = 10) 
t2 = proc.time()
running_time = t2 - t1; running_time # running time


###################################################
### code chunk number 9: PLSDA-analysis.Rnw:244-246
###################################################
# perf.plsda.srbct$error.rate  # error rates
plot(perf.plsda.srbct, col = color.mixo(5:7), sd = TRUE, legend.position = "horizontal")


###################################################
### code chunk number 10: PLSDA-analysis.Rnw:253-254
###################################################
auc.plsda = auroc(srbct.plsda, roc.comp = 6)


###################################################
### code chunk number 11: PLSDA-analysis.Rnw:267-285 (eval = FALSE)
###################################################
## # run internally and saved
## 
## set.seed(2543) # for reproducibility
## # grid of possible keepX values that will be tested for each component
## list.keepX <- c(1:10,  seq(20, 300, 10))  
## 
## t1 = proc.time()  
## tune.splsda.srbct <- tune.splsda(X, Y, ncomp = 6, validation = 'Mfold', folds = 5, 
##                            progressBar = FALSE, dist = 'max.dist', measure = "BER",
##                           test.keepX = list.keepX, nrepeat = 10)#, cpus = 2)
## t2 = proc.time()
## running_time = t2 - t1; running_time # running time
## 
## error <- tune.splsda.srbct$error.rate
## ncomp <- tune.splsda.srbct$choice.ncomp$ncomp
## select.keepX <- tune.splsda.srbct$choice.keepX[1:ncomp]
## 
## save(tune.splsda.srbct, ncomp, list.keepX, error, select.keepX, running_time,  file = 'RData/result-SRBCT-sPLSDA.RData')


###################################################
### code chunk number 12: PLSDA-analysis.Rnw:288-289
###################################################
load('RData/result-SRBCT-sPLSDA.Rdata')


###################################################
### code chunk number 13: PLSDA-analysis.Rnw:292-302 (eval = FALSE)
###################################################
## set.seed(2543) # for reproducibility
## # grid of possible keepX values that will be tested for each component
## list.keepX <- c(1:10,  seq(20, 300, 10))
## 
## t1 = proc.time()  
## tune.splsda.srbct <- tune.splsda(X, Y, ncomp = 6, validation = 'Mfold', folds = 5, 
##                            progressBar = TRUE, dist = 'max.dist', measure = "BER",
##                           test.keepX = list.keepX, nrepeat = 10)
## t2 = proc.time()
## running_time = t2 - t1; running_time # running time


###################################################
### code chunk number 14: PLSDA-analysis.Rnw:305-306
###################################################
running_time


###################################################
### code chunk number 15: PLSDA-analysis.Rnw:309-310 (eval = FALSE)
###################################################
## error <- tune.splsda.srbct$error.rate  # error rate per component for the keepX grid


###################################################
### code chunk number 16: PLSDA-analysis.Rnw:314-316 (eval = FALSE)
###################################################
## ncomp <- tune.splsda.srbct$choice.ncomp$ncomp # optimal number of components based on t-tests
## ncomp


###################################################
### code chunk number 17: PLSDA-analysis.Rnw:319-320
###################################################
ncomp


###################################################
### code chunk number 18: PLSDA-analysis.Rnw:324-326 (eval = FALSE)
###################################################
## select.keepX <- tune.splsda.srbct$choice.keepX[1:ncomp]  # optimal number of variables to select
## select.keepX


###################################################
### code chunk number 19: PLSDA-analysis.Rnw:328-329
###################################################
select.keepX


###################################################
### code chunk number 20: PLSDA-analysis.Rnw:337-338
###################################################
plot(tune.splsda.srbct, col = color.jet(6))


###################################################
### code chunk number 21: PLSDA-analysis.Rnw:347-348
###################################################
splsda.srbct <- splsda(X, Y, ncomp = ncomp, keepX = select.keepX) 


###################################################
### code chunk number 22: PLSDA-analysis.Rnw:354-358
###################################################
plotIndiv(splsda.srbct, comp = c(1,2),
          group = srbct$class, ind.names = FALSE, 
          ellipse = TRUE, legend = TRUE,
          title = 'sPLS-DA on SRBCT, comp 1 & 2')


###################################################
### code chunk number 23: PLSDA-analysis.Rnw:365-369
###################################################
plotIndiv(splsda.srbct, comp = c(1,3),
          group = srbct$class, ind.names = FALSE, 
          ellipse = TRUE, legend = TRUE,
          title = 'sPLS-DA on SRBCT, comp 1 & 3')


###################################################
### code chunk number 24: PLSDA-analysis.Rnw:377-378
###################################################
auc.splsda = auroc(splsda.srbct, roc.comp = 2)


###################################################
### code chunk number 25: PLSDA-analysis.Rnw:383-384
###################################################
auc.splsda = auroc(splsda.srbct, roc.comp = ncomp)


###################################################
### code chunk number 26: PLSDA-analysis.Rnw:390-398
###################################################
set.seed(40) # for reproducibility, only when the `cpus' argument is not used

t1 = proc.time()  
perf.srbct <- perf(splsda.srbct, validation = "Mfold", folds = 5,
                   dist = 'max.dist', nrepeat = 10,
                   progressBar = FALSE) 
t2 = proc.time()
running_time = t2 - t1; running_time


###################################################
### code chunk number 27: PLSDA-analysis.Rnw:402-405
###################################################
# perf.srbct  # lists the different outputs
perf.srbct$error.rate
plot(perf.srbct, col = color.mixo(5))


###################################################
### code chunk number 28: PLSDA-analysis.Rnw:412-420
###################################################
par(mfrow=c(1,3))
plot(perf.srbct$features$stable[[1]], type = 'h', ylab = 'Stability', 
     xlab = 'Features', main = 'Comp 1', las =2)
plot(perf.srbct$features$stable[[2]], type = 'h', ylab = 'Stability', 
     xlab = 'Features', main = 'Comp 2', las =2)
plot(perf.srbct$features$stable[[3]], type = 'h', ylab = 'Stability', 
     xlab = 'Features', main = 'Comp 3', las =2)
par(mfrow=c(1,1))


###################################################
### code chunk number 29: PLSDA-analysis.Rnw:426-433
###################################################
# here we match the selected variables to the stable features
ind.match = match(selectVar(splsda.srbct, comp = 1)$name, 
                  names(perf.srbct$features$stable[[1]]))
#extract the frequency of selection of those selected variables
Freq = as.numeric(perf.srbct$features$stable[[1]][ind.match])

data.frame(selectVar(splsda.srbct, comp = 1)$value, Freq)


###################################################
### code chunk number 30: PLSDA-analysis.Rnw:440-442
###################################################
plotLoadings(splsda.srbct, comp = 1, title = 'Loadings on comp 1', 
             contrib = 'max', method = 'mean')


###################################################
### code chunk number 31: PLSDA-analysis.Rnw:446-448
###################################################
plotLoadings(splsda.srbct, comp = 2, title = 'Loadings on comp 2', 
             contrib = 'max', method = 'mean')


###################################################
### code chunk number 32: PLSDA-analysis.Rnw:451-453
###################################################
plotLoadings(splsda.srbct, comp = 3, title = 'Loadings on comp 3', 
             contrib = 'max', method = 'mean')


###################################################
### code chunk number 33: PLSDA-analysis.Rnw:459-461
###################################################
plotLoadings(splsda.srbct, comp = 1, title = 'Loadings on comp 1', 
             contrib = 'min', method = 'mean')


###################################################
### code chunk number 34: PLSDA-analysis.Rnw:467-468
###################################################
cim(splsda.srbct)


###################################################
### code chunk number 35: PLSDA-analysis.Rnw:471-472
###################################################
cim(splsda.srbct, comp=1, title ="Component 1")


###################################################
### code chunk number 36: PLSDA-analysis.Rnw:478-479
###################################################
plotArrow(splsda.srbct, legend=T)


###################################################
### code chunk number 37: PLSDA-analysis.Rnw:488-489
###################################################
sessionInfo()


###################################################
### code chunk number 38: PLSDA-analysis.Rnw:493-495
###################################################
# the end of that chapter. Command not to be run
Stangle('PLSDA-analysis.Rnw', encoding = 'utf8')


